pub enum SocketAddr {
V4(SocketAddrV4),
V6(SocketAddrV6),
}Expand description
An internet socket address, either IPv4 or IPv6.
Internet socket addresses consist of an IP address, a 16-bit port number, as well
as possibly some version-dependent additional information. See SocketAddrV4โs and
SocketAddrV6โs respective documentation for more details.
Portability
SocketAddr is intended to be a portable representation of socket addresses and is likely not
the same as the internal socket address type used by the target operating systemโs API. Like all
repr(Rust) structs, however, its exact layout remains undefined and should not be relied upon
between builds.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!("127.0.0.1:8080".parse(), Ok(socket));
assert_eq!(socket.port(), 8080);
assert_eq!(socket.is_ipv4(), true);Variants
Implementations
Sourceimpl SocketAddr
impl SocketAddr
Sourcepub fn parse_ascii(b: &[u8]) -> Result<SocketAddr, AddrParseError>
๐ฌThis is a nightly-only experimental API. (addr_parse_ascii)
pub fn parse_ascii(b: &[u8]) -> Result<SocketAddr, AddrParseError>
addr_parse_ascii)Parse a socket address from a slice of bytes.
#![feature(addr_parse_ascii)]
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr};
let socket_v4 = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
let socket_v6 = SocketAddr::new(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1)), 8080);
assert_eq!(SocketAddr::parse_ascii(b"127.0.0.1:8080"), Ok(socket_v4));
assert_eq!(SocketAddr::parse_ascii(b"[::1]:8080"), Ok(socket_v6));Sourceimpl SocketAddr
impl SocketAddr
1.7.0 (const: 1.69.0) ยท Sourcepub const fn new(ip: IpAddr, port: u16) -> SocketAddr
pub const fn new(ip: IpAddr, port: u16) -> SocketAddr
Creates a new socket address from an IP address and a port number.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)));
assert_eq!(socket.port(), 8080);1.7.0 (const: 1.69.0) ยท Sourcepub const fn ip(&self) -> IpAddr
pub const fn ip(&self) -> IpAddr
Returns the IP address associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)));1.9.0 (const: 1.87.0) ยท Sourcepub const fn set_ip(&mut self, new_ip: IpAddr)
pub const fn set_ip(&mut self, new_ip: IpAddr)
Changes the IP address associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let mut socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
socket.set_ip(IpAddr::V4(Ipv4Addr::new(10, 10, 0, 1)));
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(10, 10, 0, 1)));1.0.0 (const: 1.69.0) ยท Sourcepub const fn port(&self) -> u16
pub const fn port(&self) -> u16
Returns the port number associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.port(), 8080);1.9.0 (const: 1.87.0) ยท Sourcepub const fn set_port(&mut self, new_port: u16)
pub const fn set_port(&mut self, new_port: u16)
Changes the port number associated with this socket address.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let mut socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
socket.set_port(1025);
assert_eq!(socket.port(), 1025);1.16.0 (const: 1.69.0) ยท Sourcepub const fn is_ipv4(&self) -> bool
pub const fn is_ipv4(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv4 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), true);
assert_eq!(socket.is_ipv6(), false);1.16.0 (const: 1.69.0) ยท Sourcepub const fn is_ipv6(&self) -> bool
pub const fn is_ipv6(&self) -> bool
Returns true if the IP address in this SocketAddr is an
IPv6 address, and false otherwise.
Examples
use std::net::{IpAddr, Ipv6Addr, SocketAddr};
let socket = SocketAddr::new(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 65535, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), false);
assert_eq!(socket.is_ipv6(), true);Trait Implementations
impl<'a> AddAnyAttr for SocketAddr
impl<'a> AddAnyAttr for SocketAddr
type Output<SomeNewAttr: Attribute> = SocketAddr
type Output<SomeNewAttr: Attribute> = SocketAddr
fn add_any_attr<NewAttr>(
self,
_attr: NewAttr,
) -> <SocketAddr as AddAnyAttr>::Output<NewAttr>where
NewAttr: Attribute,
fn add_any_attr<NewAttr>(
self,
_attr: NewAttr,
) -> <SocketAddr as AddAnyAttr>::Output<NewAttr>where
NewAttr: Attribute,
impl AttributeValue for SocketAddr
impl AttributeValue for SocketAddr
type AsyncOutput = SocketAddr
type AsyncOutput = SocketAddr
type State = (Element, SocketAddr)
type State = (Element, SocketAddr)
type Cloneable = SocketAddr
type Cloneable = SocketAddr
FnMut() continues mutating the same
closure), but making a String cloneable does not necessarily need to make it an
Arc<str>, as two different clones of a String will still have the same value.type CloneableOwned = SocketAddr
type CloneableOwned = SocketAddr
'static. This is used for spreading across types when the
spreadable attribute needs to be owned. In some cases (&'a str to Arc<str>, etc.) the owned
cloneable type has worse performance than the cloneable type, so they are separate.fn to_template(_key: &str, _buf: &mut String)
fn to_template(_key: &str, _buf: &mut String)
<template>.fn hydrate<const FROM_SERVER: bool>(
self,
key: &str,
el: &Element,
) -> <SocketAddr as AttributeValue>::State
fn hydrate<const FROM_SERVER: bool>( self, key: &str, el: &Element, ) -> <SocketAddr as AttributeValue>::State
<template>.fn build(self, el: &Element, key: &str) -> <SocketAddr as AttributeValue>::State
fn build(self, el: &Element, key: &str) -> <SocketAddr as AttributeValue>::State
fn rebuild(self, key: &str, state: &mut <SocketAddr as AttributeValue>::State)
fn rebuild(self, key: &str, state: &mut <SocketAddr as AttributeValue>::State)
fn into_cloneable(self) -> <SocketAddr as AttributeValue>::Cloneable
fn into_cloneable(self) -> <SocketAddr as AttributeValue>::Cloneable
fn into_cloneable_owned(self) -> <SocketAddr as AttributeValue>::CloneableOwned
fn into_cloneable_owned(self) -> <SocketAddr as AttributeValue>::CloneableOwned
'static.fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
async fn resolve(self) -> <SocketAddr as AttributeValue>::AsyncOutput
async fn resolve(self) -> <SocketAddr as AttributeValue>::AsyncOutput
Sourceimpl<'de, __Context> BorrowDecode<'de, __Context> for SocketAddr
impl<'de, __Context> BorrowDecode<'de, __Context> for SocketAddr
Sourcefn borrow_decode<D>(decoder: &mut D) -> Result<SocketAddr, DecodeError>where
D: BorrowDecoder<'de, Context = __Context>,
fn borrow_decode<D>(decoder: &mut D) -> Result<SocketAddr, DecodeError>where
D: BorrowDecoder<'de, Context = __Context>,
1.0.0 ยท Sourceimpl Clone for SocketAddr
impl Clone for SocketAddr
Sourcefn clone(&self) -> SocketAddr
fn clone(&self) -> SocketAddr
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Connected<IncomingStream<'_, TcpListener>> for SocketAddr
impl Connected<IncomingStream<'_, TcpListener>> for SocketAddr
fn connect_info(stream: IncomingStream<'_, TcpListener>) -> SocketAddr
fn connect_info(stream: IncomingStream<'_, TcpListener>) -> SocketAddr
impl Connected<SocketAddr> for SocketAddr
impl Connected<SocketAddr> for SocketAddr
fn connect_info(remote_addr: SocketAddr) -> SocketAddr
fn connect_info(remote_addr: SocketAddr) -> SocketAddr
1.0.0 ยท Sourceimpl Debug for SocketAddr
impl Debug for SocketAddr
Sourceimpl<Context> Decode<Context> for SocketAddr
impl<Context> Decode<Context> for SocketAddr
Sourcefn decode<D>(decoder: &mut D) -> Result<SocketAddr, DecodeError>where
D: Decoder<Context = Context>,
fn decode<D>(decoder: &mut D) -> Result<SocketAddr, DecodeError>where
D: Decoder<Context = Context>,
Sourceimpl<'de> Deserialize<'de> for SocketAddr
Available on crate feature std or non-no_core_net only.
impl<'de> Deserialize<'de> for SocketAddr
std or non-no_core_net only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<SocketAddr, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<SocketAddr, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
1.0.0 ยท Sourceimpl Display for SocketAddr
impl Display for SocketAddr
Sourceimpl Encode for SocketAddr
impl Encode for SocketAddr
1.17.0 (const: unstable) ยท Sourceimpl<I> From<(I, u16)> for SocketAddr
impl<I> From<(I, u16)> for SocketAddr
Sourcefn from(pieces: (I, u16)) -> SocketAddr
fn from(pieces: (I, u16)) -> SocketAddr
Converts a tuple struct (Into<IpAddr>, u16) into a SocketAddr.
This conversion creates a SocketAddr::V4 for an IpAddr::V4
and creates a SocketAddr::V6 for an IpAddr::V6.
u16 is treated as port of the newly created SocketAddr.
impl From<SocketAddr> for SockAddr
impl From<SocketAddr> for SockAddr
fn from(addr: SocketAddr) -> SockAddr
fn from(addr: SocketAddr) -> SockAddr
impl From<SocketAddr> for SocketAddrAny
impl From<SocketAddr> for SocketAddrAny
fn from(from: SocketAddr) -> SocketAddrAny
fn from(from: SocketAddr) -> SocketAddrAny
1.16.0 (const: unstable) ยท Sourceimpl From<SocketAddrV4> for SocketAddr
impl From<SocketAddrV4> for SocketAddr
Sourcefn from(sock4: SocketAddrV4) -> SocketAddr
fn from(sock4: SocketAddrV4) -> SocketAddr
Converts a SocketAddrV4 into a SocketAddr::V4.
1.16.0 (const: unstable) ยท Sourceimpl From<SocketAddrV6> for SocketAddr
impl From<SocketAddrV6> for SocketAddr
Sourcefn from(sock6: SocketAddrV6) -> SocketAddr
fn from(sock6: SocketAddrV6) -> SocketAddr
Converts a SocketAddrV6 into a SocketAddr::V6.
1.0.0 ยท Sourceimpl FromStr for SocketAddr
impl FromStr for SocketAddr
Sourcetype Err = AddrParseError
type Err = AddrParseError
Sourcefn from_str(s: &str) -> Result<SocketAddr, AddrParseError>
fn from_str(s: &str) -> Result<SocketAddr, AddrParseError>
s to return a value of this type. Read more1.0.0 ยท Sourceimpl Hash for SocketAddr
impl Hash for SocketAddr
1.0.0 ยท Sourceimpl Ord for SocketAddr
impl Ord for SocketAddr
Sourcefn cmp(&self, other: &SocketAddr) -> Ordering
fn cmp(&self, other: &SocketAddr) -> Ordering
1.21.0 ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.0.0 ยท Sourceimpl PartialEq for SocketAddr
impl PartialEq for SocketAddr
1.0.0 ยท Sourceimpl PartialOrd for SocketAddr
impl PartialOrd for SocketAddr
impl PatchField for SocketAddr
impl PatchField for SocketAddr
fn patch_field(
&mut self,
new: SocketAddr,
path: &StorePath,
notify: &mut dyn FnMut(&StorePath),
)
fn patch_field( &mut self, new: SocketAddr, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )
impl PatchField for SocketAddr
impl PatchField for SocketAddr
fn patch_field(
&mut self,
new: SocketAddr,
path: &StorePath,
notify: &mut dyn FnMut(&StorePath),
)
fn patch_field( &mut self, new: SocketAddr, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )
impl Render for SocketAddr
impl Render for SocketAddr
type State = SocketAddrState
type State = SocketAddrState
fn build(self) -> <SocketAddr as Render>::State
fn build(self) -> <SocketAddr as Render>::State
fn rebuild(self, state: &mut <SocketAddr as Render>::State)
fn rebuild(self, state: &mut <SocketAddr as Render>::State)
impl RenderHtml for SocketAddr
impl RenderHtml for SocketAddr
const MIN_LENGTH: usize = 0usize
const MIN_LENGTH: usize = 0usize
type AsyncOutput = SocketAddr
type AsyncOutput = SocketAddr
type Owned = SocketAddr
type Owned = SocketAddr
'static.fn dry_resolve(&mut self)
fn dry_resolve(&mut self)
async fn resolve(self) -> <SocketAddr as RenderHtml>::AsyncOutput
async fn resolve(self) -> <SocketAddr as RenderHtml>::AsyncOutput
fn to_html_with_buf(
self,
buf: &mut String,
position: &mut Position,
_escape: bool,
_mark_branches: bool,
_extra_attrs: Vec<AnyAttribute>,
)
fn to_html_with_buf( self, buf: &mut String, position: &mut Position, _escape: bool, _mark_branches: bool, _extra_attrs: Vec<AnyAttribute>, )
fn hydrate<const FROM_SERVER: bool>(
self,
cursor: &Cursor,
position: &PositionState,
) -> <SocketAddr as Render>::State
fn hydrate<const FROM_SERVER: bool>( self, cursor: &Cursor, position: &PositionState, ) -> <SocketAddr as Render>::State
fn into_owned(self) -> <SocketAddr as RenderHtml>::Owned
fn into_owned(self) -> <SocketAddr as RenderHtml>::Owned
'static.const EXISTS: bool = true
const EXISTS: bool = true
fn to_html_branching(self) -> Stringwhere
Self: Sized,
fn to_html_branching(self) -> Stringwhere
Self: Sized,
fn to_html_stream_in_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_in_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_in_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_in_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_stream_out_of_order_branching(self) -> StreamBuilderwhere
Self: Sized,
fn to_html_async_with_buf<const OUT_OF_ORDER: bool>(
self,
buf: &mut StreamBuilder,
position: &mut Position,
escape: bool,
mark_branches: bool,
extra_attrs: Vec<AnyAttribute>,
)where
Self: Sized,
fn to_html_async_with_buf<const OUT_OF_ORDER: bool>(
self,
buf: &mut StreamBuilder,
position: &mut Position,
escape: bool,
mark_branches: bool,
extra_attrs: Vec<AnyAttribute>,
)where
Self: Sized,
fn hydrate_async(
self,
cursor: &Cursor,
position: &PositionState,
) -> impl Future<Output = Self::State>
fn hydrate_async( self, cursor: &Cursor, position: &PositionState, ) -> impl Future<Output = Self::State>
fn hydrate_from<const FROM_SERVER: bool>(self, el: &Element) -> Self::Statewhere
Self: Sized,
fn hydrate_from<const FROM_SERVER: bool>(self, el: &Element) -> Self::Statewhere
Self: Sized,
RenderHtml::hydrate, beginning at the given element.fn hydrate_from_position<const FROM_SERVER: bool>(
self,
el: &Element,
position: Position,
) -> Self::Statewhere
Self: Sized,
fn hydrate_from_position<const FROM_SERVER: bool>(
self,
el: &Element,
position: Position,
) -> Self::Statewhere
Self: Sized,
RenderHtml::hydrate, beginning at the given element and position.Sourceimpl Serialize for SocketAddr
Available on crate feature std or non-no_core_net only.
impl Serialize for SocketAddr
std or non-no_core_net only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
impl SocketAddrArg for SocketAddr
impl SocketAddrArg for SocketAddr
unsafe fn with_sockaddr<R>(
&self,
f: impl FnOnce(*const SocketAddrOpaque, u32) -> R,
) -> R
unsafe fn with_sockaddr<R>( &self, f: impl FnOnce(*const SocketAddrOpaque, u32) -> R, ) -> R
unsafe fn write_sockaddr(&self, storage: *mut SocketAddrStorage) -> u32
unsafe fn write_sockaddr(&self, storage: *mut SocketAddrStorage) -> u32
SocketAddrStorage. Read more1.0.0 ยท Sourceimpl ToSocketAddrs for SocketAddr
impl ToSocketAddrs for SocketAddr
Sourcetype Iter = IntoIter<SocketAddr>
type Iter = IntoIter<SocketAddr>
Sourcefn to_socket_addrs(&self) -> Result<IntoIter<SocketAddr>, Error>
fn to_socket_addrs(&self) -> Result<IntoIter<SocketAddr>, Error>
SocketAddrs. Read moreimpl<'a> ToTemplate for SocketAddr
impl<'a> ToTemplate for SocketAddr
fn to_template(
buf: &mut String,
_class: &mut String,
_style: &mut String,
_inner_html: &mut String,
position: &mut Position,
)
fn to_template( buf: &mut String, _class: &mut String, _style: &mut String, _inner_html: &mut String, position: &mut Position, )
<template> that corresponds
to a view of a particular type.impl TryFrom<SocketAddrAny> for SocketAddr
impl TryFrom<SocketAddrAny> for SocketAddr
fn try_from(
value: SocketAddrAny,
) -> Result<SocketAddr, <SocketAddr as TryFrom<SocketAddrAny>>::Error>
fn try_from( value: SocketAddrAny, ) -> Result<SocketAddr, <SocketAddr as TryFrom<SocketAddrAny>>::Error>
Convert if the address is an IPv4 or IPv6 address.
Returns Err(Errno::AFNOSUPPORT) if the address family is not IPv4 or
IPv6.
impl Copy for SocketAddr
impl Eq for SocketAddr
impl StructuralPartialEq for SocketAddr
impl ToSocketAddrs for SocketAddr